@@ -21,6 +21,8 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 ##
+
+
 import argparse
 import cmd
 import glob
@@ -33,12 +35,9 @@ import tempfile
 
 import colorama
 import serial
-
 from mp import version
 from mp.conbase import ConError
-from mp.mpfexp import MpFileExplorer
-from mp.mpfexp import MpFileExplorerCaching
-from mp.mpfexp import RemoteIOError
+from mp.mpfexp import MpFileExplorer, MpFileExplorerCaching, RemoteIOError
 from mp.pyboard import PyboardError
 from mp.tokenizer import Tokenizer
 
@@ -259,8 +258,8 @@ class MpFileShell(cmd.Cmd):
 
     def do_pwd(self, args):
         """pwd
-        Print current remote directory.
-        """
+         Print current remote directory.
+         """
         if self.__is_open():
             print(self.fe.pwd())
 
@@ -582,7 +581,7 @@ class MpFileShell(cmd.Cmd):
             except PyboardError as e:
                 self.__error(str(e))
 
-    def do_repl(self, args):
+    def do_repl(self, args=[], start_main=False):
         """repl
         Enter Micropython REPL.
         """
@@ -606,9 +605,10 @@ class MpFileShell(cmd.Cmd):
                 self.repl = Term(self.fe.con)
 
                 if platform.system() == "Windows":
-                    self.repl.exit_character = chr(0x11)
+                    self.repl.exit_character = chr(0x11) # ctrl-q
+                    self.repl.exit_character = chr(0x18) # ctrl-X
                 else:
-                    self.repl.exit_character = chr(0x1D)
+                    self.repl.exit_character = chr(0x1D) # ctrl-]
 
                 self.repl.raw = True
                 self.repl.set_rx_encoding("UTF-8")
@@ -621,10 +621,12 @@ class MpFileShell(cmd.Cmd):
             self.fe.teardown()
             self.repl.start()
 
-            if self.repl.exit_character == chr(0x11):
-                print("\n*** Exit REPL with Ctrl+Q ***")
-            else:
-                print("\n*** Exit REPL with Ctrl+] ***")
+            ctrl_char = {chr(0x11): 'Q', chr(0x18): 'X'}.get(self.repl.exit_character, ']')
+            print(f"\n*** Exit REPL with Ctrl+{ctrl_char} ***")
+
+            if start_main:
+                print("Start 'main.py' (by sending <ctrl-D>)")
+                self.repl.serial.write(b'\x04')
 
             try:
                 self.repl.join(True)
@@ -815,7 +817,7 @@ def main():
 
         if platform.system() == "Windows":
             mpfs.use_rawinput = True
-
+            
         f = open(args.script, "r")
         script = ""
 
